@@ -1,3 +1,5 @@
+## one instance of assign replaced by justDoIt
+
 Menu.importrdacsv <- function(){
 ## Aktualisierung des neuen Namens bei nderung in designsel funktioniert noch nicht
 ## tkbind event vermutlich nicht gut gewhlt!
@@ -53,8 +55,10 @@ onOK <- function(){
             errorCondition(window=topdes2,recall=Menu.importrdacsv, message=gettextRcmdr(hilf))
              return()
             }
-
-        assign(newname, hilf, envir=.GlobalEnv)
+        putRcmdr("hilf", hilf)
+        ## replace assign by justDoIt; assign(newname, hilf, envir=.GlobalEnv)
+        justDoIt(paste(newname, "<- getRcmdr(\"hilf\")"))
+        rm("hilf", pos="RcmdrEnv")
         logger(paste(newname, "<-", command))
         activeDataSet(newname)
         putRcmdr("fileVar", tclVar(""))
