@@ -42,18 +42,25 @@ Menu.rsmmodel <- function(){
     onOK <- function(){
         response <- getSelection(sel.resps)
         fn <- getSelection(sel.factors)
+        #fn is something like x1<A
+        #the following gets the A from there
+        #if (length(grep("<",fn)>0)) 
+        #fn[grep("<",fn)] <- sapply(strsplit(fn[grep("<",fn)],"<", fixed=TRUE), function(obj) obj[2])
         putRcmdr("resphilf", response)
         putRcmdr("facthilf", paste("c(", paste(dquote(fn),collapse=","), ")", sep=""))
+
         putRcmdr("coded", as.numeric(tclvalue(codedcbVariable)))
+
         command <- paste("rsmformula(",.activeDataSet,", response=", dquote(response), 
               ", factor.names=c(", paste(dquote(fn),collapse=","), "), degree=", tclvalue(degreeVar), 
               ", coded=", as.logical(getRcmdr("coded")), ")")
+
         hilf <- justDoItDoE(command)
         if (class(hilf)[1]=="try-error") {
             errorCondition(window=top,recall=Menu.rsmmodel, message=gettextRcmdr(hilf))
              return()
             }
-        
+
         if (!is.null(di$responselist)){
           if (di$response.names[1]==di$responselist[1,1]){
           tk_messageBox(type="ok","This is a wide format repeated measurement or parameter design.\n
@@ -74,16 +81,20 @@ Menu.rsmmodel <- function(){
         if (length(grep("splitplot", di$type))>0) 
           warning("The default analysis can be misleading for splitplot designs!
           Whole-plot factors are often subject to much more variability than split-plot factors.")
+          
+          
           putRcmdr("degree", tclvalue(degreeVar))
           closeDialog()
           Menu.rsm(response=resphilf, factor.names=eval(parse(text=facthilf)))
         }
+        
         }
     OKCancelHelp(helpSubject="Menu.rsmmodel")
     tkgrid(getFrame(sel.resps), getFrame(sel.factors), sticky="n")
-    tkgrid(codingcb, degreelab, degreeEntry, sticky="w")
-    tkgrid.configure(degreeEntry, sticky="nse")
-    tkgrid.configure(degreelab, sticky="nse")
+    tkgrid(codingcb, columnspan=2)
+    tkgrid(degreelab, degreeEntry, sticky="w")
+    #tkgrid.configure(degreeEntry, sticky="nse")
+    tkgrid.configure(degreelab, sticky="e")
     tkgrid(buttonsFrame, sticky="w")
-    dialogSuffix(window=top, rows=2, columns=1)
+    dialogSuffix(window=top, rows=2, columns=2)
     }
