@@ -13,5 +13,7 @@ justDoItDoE <- function (command)
     result <- try(eval(parse(text = command),envir = .GlobalEnv))
     ## warnings only, if no error abort
     if (!class(result)[1]=="try-error") Rcmdr:::checkWarnings(readLines(messages.connection))
-    result
+    if (getRcmdr("RStudio")) 
+        Sys.sleep(0)
+     result
 }
